<?xml version="1.0" ?><!DOCTYPE TS><TS language="gl" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Existe vida máis aló do navegador!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versión %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Baixo licenza por: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 é Software libre, mais o seu desenvolvemento leva un tempo precioso.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Faga unha &lt;a href=&apos;%1&apos;&gt;doazón&lt;/a&gt; para axudar na continuación do desenvolvemento de %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Traducir %1 ao seu idioma empregando %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation>Coa tecnoloxía de %1</translation>
    </message>
    <message>
        <source>Open-source software</source>
        <translation>Software de fontes abertas</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Icona deseñada por %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Publicado baixo a &lt;a href=&apos;%1&apos;&gt;Licenza pública Xeral GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Pechar</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Introduce os detalles da túa licenza</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Correo electrónico:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Código:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Licenza %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Esta demo caducou.</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>A versión completa permite ver os vídeos sen interrupcións.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Sen licenza o aplicativo expira en %1 días.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Ao comprar a versión completa, tamén vai apoiar o traballo arreo que puxen en crear %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Usar a demostración</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Introducir a licenza</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Comprar a licenza</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Descarga</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Por %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation><numerusform>Dispón dun novo vídeo</numerusform><numerusform>Dispón de  %n novos vídeos</numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Todos os vídeos</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Vídeos non vistos</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Última actualización</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Último engadido</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Último visto</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Máis vistos</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Ordenar por</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Marcar todos como vistos</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Amosar a actualización</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Non ten subscricións. Utilice o símbolo da estrela para subscribirse ás canles.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Todos os vídeos</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Vídeos non vistos</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Marcar como visto</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Darse de baixa</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Neste momento non ten subscricións de actualización.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Agora mesmo</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation><numerusform>Hai %n hora</numerusform><numerusform>Hai %n horas</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation><numerusform>Hai %n dia</numerusform><numerusform>Hai %n dias</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation><numerusform>Hai %n mes</numerusform><numerusform>Hai %n meses</numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation>K</translation>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation>M</translation>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 vistas</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation><numerusform>Hai %n semana</numerusform><numerusform>Hai %n semanas</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bytes/seg</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/seg</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/seg</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 restantes</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 descargado en %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Rematou a descarga</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation><numerusform>%n descarga</numerusform><numerusform>%n descargas</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Cambiar a localización...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Escolla a localización da descarga</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Cambiada a localización da descarga.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>A descarga actual aínda se fai na localización anterior.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Descargando en: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Descargas</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>O ficheiro executable foi manipulado, quizais por un virus.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 non se executará. Probe a instalalo de novo.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Saír</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Volver instalar</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Deter</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Reproducir/deter</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Parar a reprodución despois da pista actual</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Seguinte pista</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Pista anterior</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Aumentar volume</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Diminuír volume</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Buscar cara adiante</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Buscar cara atrás</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Atopar vídeos e canles por palabra clave</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Examinar</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Examinar vídeos por categoría</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Subscricións</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Subscricións a canles</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Síntase cómodo</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Xanela</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimizar</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Parar</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Parara a reprodución e volver á vista de busca</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>A&amp;nterior</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Ir á pista anterior</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Saltar</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Saltar ao seguinte vídeo</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Reproducir</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Continuar a reprodución</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Ir á pantalla completa</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>Modo &amp;compacto</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Agochar a lista de reprodución e a barra de tarefas</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Abrir a páxina de &amp;YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Ir á páxina de vídeos YouTube e por en pausa a reprodución</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Copiar a &amp;ligazón de YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Copiar a ligazón actual de vídeo de YouTube no portapapeis</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Copiar o &amp;URL do fluxo de vídeo</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Copiar o URL actual do fluxo de vídeo no portapapeis</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Atopar &amp;partes de vídeos</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Buscar pezas doutro vídeo agardando sexan na orde correcta</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Retirar</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Retirar os vídeos seleccionados da lista de reprodución</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mover cara &amp;arriba</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Mover cara arriba os vídeos seleccionados na lista de reprodución</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mover cara a&amp;baixo</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Mover cara abaixo os vídeos seleccionados na lista de reprodución</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;Limpar as buscas recentes</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Limpar o historial de buscas. Non se pode desfacer.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Saír</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Deica logo</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Sitio &amp;web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 na web</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Facer unha &amp;doazón</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Por favor apoie o desenvolvemento continuo de %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Sobre</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Información acerca de %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Silenciar o volume</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>Comezar a reprodución &amp;manualmente</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Comezar manualmente a reprodución dos vídeos</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Descargas</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Amosar os detalles sobre as descargas de vídeo</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Descarga</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Descargando o vídeo actual</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>Facer unha &amp;captura</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Subscribirse á canle</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Compartir o vídeo actual empregando %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;Correo-e</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Correo-e</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Pechar</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Flotante e arriba</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Deter despois deste vídeo</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Informar dun erro...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Afinar a busca...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Máis...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>Vídeos &amp;relacionados</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Ver vídeos relacionados co actual</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Abrir no &amp;navegador</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>Modo restrinxido</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>Agochar os vídeos que poidan conter contido inadecuado</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation>Alternar a barra do &amp;menú</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menú</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Gustoulle %1? Cualifíqueo!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Mercar %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplicativo</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Reproducir</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Lista de reprodución</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Vídeo</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Compartir</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>A&amp;xuda</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Prema %1 para aumentar o volume, %2 para diminuílo</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Escolla a localización do seu contido</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Abrindo %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Desexa saír de %1 cunha descarga en proceso?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Se pecha %1 agora, esta descarga vai seren cancelada.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Pechar e cancelar a descarga</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Agardar a que remate a descarga</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Produciuse un erro: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Deter</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Deter a reprodución</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Cargando...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Abandonar a &amp;pantalla completa</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tempo restante: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volume ao %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>O volume está silenciado</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>O volume non está silenciado</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Resolución máxima de vídeo fixada en %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>A súa intimidade agora está segura</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Descargas completadas</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 versión %2 xa está dispoñíbel.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Lembrar máis adiante</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation>Aínda pode acceder á barra de menús premendo a tecla ALT</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Agora pode pegar a ligazón de YouTube noutro aplicativo</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Agora pode pegar o URL do fluxo de vídeo noutro aplicativo</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>A ligazón ten validez só por un tempo limitado.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Descargando %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>de</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>parte</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>episodio</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Enviado dende %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Darse de baixa de %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Subscribirse a %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation>Cambiado a %1</translation>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Non está subscrito a %1</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>Subscrito a %1</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Hai unha nova versión de %1 dispoñible!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 está agora dispoñible. Tes %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Quere descargala agora?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Omitir esta versión</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Lembremo máis adiante</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Instalar a actualización</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation>Deleccione un vídeo</translation>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 de %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Preparando</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Produciuse un fallo</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Completada</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Detida</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Deter a descarga</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Amosar en %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Abrir o cartafol pai</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Reiniciar a descarga</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Amosar %1 máis</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Non hai vídeos</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Non hai máis vídeos</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Ordenar por</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Relevancia</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Contador de vistas</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Cualificación</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Calquera momento</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hoxe</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 días</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 días</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Curto</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Longo</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Menos de 4 minutos</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Entre 4 e 20 minutos</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Máis de 20 minutos</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Calidade</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>Alta definición</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p ou máis</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Feito</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Feito</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Benvido a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>para comezar a ver vídeos.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>unha palabra clave</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Introduza</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Palabra clave recente</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Canles recentes</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Obter a versión completa</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Atrás</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>A&amp;diante</translation>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Ir a %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Volver a %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Afinar a busca</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Quizás quixo dicir: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Cambiar a localización...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Captura gardada en %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Cambiada a localización da captura.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Máis popular</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Descargando a actualización...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Descargando %1...</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Alxeria</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Arxentina</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Australia</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Bélxica</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brasil</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Canada</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Colombia</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>República Checa</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Exipto</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Francia</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Alemania</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ghana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Grecia</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Hungría</translation>
    </message>
    <message>
        <source>India</source>
        <translation>India</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonesia</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Irlanda</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Israel</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Italia</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Xapón</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Xordania</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Quenia</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malaisia</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>México</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Marrocos</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Holanda</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Nova Celandia</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nixeria</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Perú</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Filipinas</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Polonia</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Rusia</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Arabia Saudí</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapur</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Suráfrica</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Corea do Sur</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>España</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Suecia</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunisia</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Turquía</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Emiratos Árabes Unidos</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Reino Unido</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Iemen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Todo o mundo</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Non é posíbel obter o fluxo de vídeo de %1</translation>
    </message>
</context>
</TS>